# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/api_key.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/identity/v1/api_key.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"9\n\x13\x43reateAPIKeyRequest\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"6\n\rAPIKeyRequest\x12\x12\n\napi_key_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"G\n\x10GetAPIKeyRequest\x12\x12\n\napi_key_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xf2\x01\n\nAPIKeyInfo\x12\x12\n\napi_key_id\x18\x01 \x01(\t\x12\x0f\n\x07\x61pi_key\x18\x02 \x01(\t\x12\x39\n\x05state\x18\x03 \x01(\x0e\x32*.spaceone.api.identity.v1.APIKeyInfo.State\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x18\n\x10last_accessed_at\x18\n \x01(\t\x12\x12\n\ncreated_at\x18\x0b \x01(\t\"2\n\x05State\x12\x0e\n\nNONE_STATE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\xe1\x01\n\x0b\x41PIKeyQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\napi_key_id\x18\x02 \x01(\t\x12:\n\x05state\x18\x03 \x01(\x0e\x32+.spaceone.api.identity.v1.APIKeyQuery.State\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"2\n\x05State\x12\x0e\n\nNONE_STATE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"Y\n\x0b\x41PIKeysInfo\x12\x35\n\x07results\x18\x01 \x03(\x0b\x32$.spaceone.api.identity.v1.APIKeyInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Z\n\x0f\x41PIKeyStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa1\x07\n\x06\x41PIKey\x12|\n\x06\x63reate\x12-.spaceone.api.identity.v1.CreateAPIKeyRequest\x1a$.spaceone.api.identity.v1.APIKeyInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/identity/v1/api-keys\x12\x89\x01\n\x06\x65nable\x12\'.spaceone.api.identity.v1.APIKeyRequest\x1a$.spaceone.api.identity.v1.APIKeyInfo\"0\x82\xd3\xe4\x93\x02*\x1a(/identity/v1/api-key/{api_key_id}/enable\x12\x8b\x01\n\x07\x64isable\x12\'.spaceone.api.identity.v1.APIKeyRequest\x1a$.spaceone.api.identity.v1.APIKeyInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/identity/v1/api-key/{api_key_id}/disable\x12t\n\x06\x64\x65lete\x12\'.spaceone.api.identity.v1.APIKeyRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/identity/v1/api-key/{api_key_id}\x12\x82\x01\n\x03get\x12*.spaceone.api.identity.v1.GetAPIKeyRequest\x1a$.spaceone.api.identity.v1.APIKeyInfo\")\x82\xd3\xe4\x93\x02#\x12!/identity/v1/api-key/{api_key_id}\x12\x93\x01\n\x04list\x12%.spaceone.api.identity.v1.APIKeyQuery\x1a%.spaceone.api.identity.v1.APIKeysInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x15/identity/v1/api-keysZ\x1e\"\x1c/identity/v1/api-keys/search\x12n\n\x04stat\x12).spaceone.api.identity.v1.APIKeyStatQuery\x1a\x17.google.protobuf.Struct\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/identity/v1/api-keys/statb\x06proto3')



_CREATEAPIKEYREQUEST = DESCRIPTOR.message_types_by_name['CreateAPIKeyRequest']
_APIKEYREQUEST = DESCRIPTOR.message_types_by_name['APIKeyRequest']
_GETAPIKEYREQUEST = DESCRIPTOR.message_types_by_name['GetAPIKeyRequest']
_APIKEYINFO = DESCRIPTOR.message_types_by_name['APIKeyInfo']
_APIKEYQUERY = DESCRIPTOR.message_types_by_name['APIKeyQuery']
_APIKEYSINFO = DESCRIPTOR.message_types_by_name['APIKeysInfo']
_APIKEYSTATQUERY = DESCRIPTOR.message_types_by_name['APIKeyStatQuery']
_APIKEYINFO_STATE = _APIKEYINFO.enum_types_by_name['State']
_APIKEYQUERY_STATE = _APIKEYQUERY.enum_types_by_name['State']
CreateAPIKeyRequest = _reflection.GeneratedProtocolMessageType('CreateAPIKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPIKEYREQUEST,
  '__module__' : 'spaceone.api.identity.v1.api_key_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateAPIKeyRequest)
  })
_sym_db.RegisterMessage(CreateAPIKeyRequest)

APIKeyRequest = _reflection.GeneratedProtocolMessageType('APIKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _APIKEYREQUEST,
  '__module__' : 'spaceone.api.identity.v1.api_key_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.APIKeyRequest)
  })
_sym_db.RegisterMessage(APIKeyRequest)

GetAPIKeyRequest = _reflection.GeneratedProtocolMessageType('GetAPIKeyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPIKEYREQUEST,
  '__module__' : 'spaceone.api.identity.v1.api_key_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetAPIKeyRequest)
  })
_sym_db.RegisterMessage(GetAPIKeyRequest)

APIKeyInfo = _reflection.GeneratedProtocolMessageType('APIKeyInfo', (_message.Message,), {
  'DESCRIPTOR' : _APIKEYINFO,
  '__module__' : 'spaceone.api.identity.v1.api_key_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.APIKeyInfo)
  })
_sym_db.RegisterMessage(APIKeyInfo)

APIKeyQuery = _reflection.GeneratedProtocolMessageType('APIKeyQuery', (_message.Message,), {
  'DESCRIPTOR' : _APIKEYQUERY,
  '__module__' : 'spaceone.api.identity.v1.api_key_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.APIKeyQuery)
  })
_sym_db.RegisterMessage(APIKeyQuery)

APIKeysInfo = _reflection.GeneratedProtocolMessageType('APIKeysInfo', (_message.Message,), {
  'DESCRIPTOR' : _APIKEYSINFO,
  '__module__' : 'spaceone.api.identity.v1.api_key_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.APIKeysInfo)
  })
_sym_db.RegisterMessage(APIKeysInfo)

APIKeyStatQuery = _reflection.GeneratedProtocolMessageType('APIKeyStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _APIKEYSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.api_key_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.APIKeyStatQuery)
  })
_sym_db.RegisterMessage(APIKeyStatQuery)

_APIKEY = DESCRIPTOR.services_by_name['APIKey']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _APIKEY.methods_by_name['create']._options = None
  _APIKEY.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\027\"\025/identity/v1/api-keys'
  _APIKEY.methods_by_name['enable']._options = None
  _APIKEY.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002*\032(/identity/v1/api-key/{api_key_id}/enable'
  _APIKEY.methods_by_name['disable']._options = None
  _APIKEY.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002+\032)/identity/v1/api-key/{api_key_id}/disable'
  _APIKEY.methods_by_name['delete']._options = None
  _APIKEY.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002#*!/identity/v1/api-key/{api_key_id}'
  _APIKEY.methods_by_name['get']._options = None
  _APIKEY.methods_by_name['get']._serialized_options = b'\202\323\344\223\002#\022!/identity/v1/api-key/{api_key_id}'
  _APIKEY.methods_by_name['list']._options = None
  _APIKEY.methods_by_name['list']._serialized_options = b'\202\323\344\223\0027\022\025/identity/v1/api-keysZ\036\"\034/identity/v1/api-keys/search'
  _APIKEY.methods_by_name['stat']._options = None
  _APIKEY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\034\"\032/identity/v1/api-keys/stat'
  _CREATEAPIKEYREQUEST._serialized_start=191
  _CREATEAPIKEYREQUEST._serialized_end=248
  _APIKEYREQUEST._serialized_start=250
  _APIKEYREQUEST._serialized_end=304
  _GETAPIKEYREQUEST._serialized_start=306
  _GETAPIKEYREQUEST._serialized_end=377
  _APIKEYINFO._serialized_start=380
  _APIKEYINFO._serialized_end=622
  _APIKEYINFO_STATE._serialized_start=572
  _APIKEYINFO_STATE._serialized_end=622
  _APIKEYQUERY._serialized_start=625
  _APIKEYQUERY._serialized_end=850
  _APIKEYQUERY_STATE._serialized_start=572
  _APIKEYQUERY_STATE._serialized_end=622
  _APIKEYSINFO._serialized_start=852
  _APIKEYSINFO._serialized_end=941
  _APIKEYSTATQUERY._serialized_start=943
  _APIKEYSTATQUERY._serialized_end=1033
  _APIKEY._serialized_start=1036
  _APIKEY._serialized_end=1965
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.repository.v1 import repository_pb2 as spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2


class RepositoryStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.register = channel.unary_unary(
                '/spaceone.api.repository.v1.Repository/register',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.CreateRepositoryRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.repository.v1.Repository/update',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.UpdateRepositoryRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryInfo.FromString,
                )
        self.deregister = channel.unary_unary(
                '/spaceone.api.repository.v1.Repository/deregister',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.repository.v1.Repository/get',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.GetRepositoryRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.repository.v1.Repository/list',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoriesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.repository.v1.Repository/stat',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class RepositoryServicer(object):
    """Missing associated documentation comment in .proto file."""

    def register(self, request, context):
        """
        desc: Registers a Repository. The parameter `name` can only include alphabets, numbers, and hyphens(-). The parameter `repository_type` can be either `local` or `remote`. The parameter `endpoint` is needed if the `repository_type` is `remote`.
        request_example: >-
        {
        "name": "Local",
        "repository_type": "local",
        "endpoint": "grpc+ssl://local-url:443"
        }
        response_example: >-
        {
        "repository_id": "repo-123456789012",
        "name": "Local",
        "repository_type": "local",
        "endpoint": "grpc+ssl://local-url:443",
        "created_at": "2022-01-01T02:27:02.924Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Repository registered. You must specify the `repository_id` of the Repository to update. You can make changes in Repository settings, including `name`.
        request_example: >-
        {
        "repository_id": "repo-123456789012",
        "name": "Local-repo"
        }
        response_example: >-
        {
        "repository_id": "repo-123456789012",
        "name": "Local-repo",
        "repository_type": "local",
        "endpoint": "grpc+ssl://local-url:443",
        "created_at": "2022-01-01T02:27:02.924Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deregister(self, request, context):
        """
        desc: Deregisters and deletes a specific Repository. You must specify the `repository_id` of the Repository to deregister.
        request_example: >-
        {
        "repository_id": "repo-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Repository. Prints detailed information about the Repository, including  `name`, `repository_type`, and `endpoint`.
        request_example: >-
        {
        "repository_id": "repo-123456789012"
        }
        response_example: >-
        {
        "repository_id": "repo-123456789012",
        "name": "Local-repo",
        "repository_type": "local",
        "endpoint": "grpc+ssl://local-url:443",
        "created_at": "2022-01-01T02:26:29.081Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Repositories regardless of `domain`. You can use a query to get a filtered list of Repositories.
        request_example: >-
        {
        "query": {},
        "repository_id": "repo-123456789012"
        }
        response_example: >-
        {
        "results": [
        {
        "repository_id": "repo-123456789012",
        "name": "Local-repo",
        "repository_type": "local",
        "endpoint": "grpc+ssl://local-url:443",
        "created_at": "2022-01-01T02:26:29.081Z"
        }
        ],
        "total_count": 1
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RepositoryServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'register': grpc.unary_unary_rpc_method_handler(
                    servicer.register,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.CreateRepositoryRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.UpdateRepositoryRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryInfo.SerializeToString,
            ),
            'deregister': grpc.unary_unary_rpc_method_handler(
                    servicer.deregister,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.GetRepositoryRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoriesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.repository.v1.Repository', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Repository(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Repository/register',
            spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.CreateRepositoryRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Repository/update',
            spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.UpdateRepositoryRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deregister(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Repository/deregister',
            spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Repository/get',
            spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.GetRepositoryRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Repository/list',
            spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryQuery.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoriesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Repository/stat',
            spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2.RepositoryStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/project_alert_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.monitoring.v1 import escalation_policy_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_escalation__policy__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5spaceone/api/monitoring/v1/project_alert_config.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a\x32spaceone/api/monitoring/v1/escalation_policy.proto\"\xaa\x02\n\x0c\x41lertOptions\x12T\n\x14notification_urgency\x18\x01 \x01(\x0e\x32\x36.spaceone.api.monitoring.v1.AlertOptions.UrgencyOption\x12N\n\rrecovery_mode\x18\x02 \x01(\x0e\x32\x37.spaceone.api.monitoring.v1.AlertOptions.RecoveryOption\"9\n\rUrgencyOption\x12\x10\n\x0cURGENCY_NONE\x10\x00\x12\x07\n\x03\x41LL\x10\x01\x12\r\n\tHIGH_ONLY\x10\x02\"9\n\x0eRecoveryOption\x12\x11\n\rRECOVERY_NONE\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\x12\n\n\x06MANUAL\x10\x02\"\xa1\x01\n\x1f\x43reateProjectAlertConfigRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x1c\n\x14\x65scalation_policy_id\x18\x02 \x01(\t\x12\x39\n\x07options\x18\x03 \x01(\x0b\x32(.spaceone.api.monitoring.v1.AlertOptions\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xa1\x01\n\x1fUpdateProjectAlertConfigRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x1c\n\x14\x65scalation_policy_id\x18\x02 \x01(\t\x12\x39\n\x07options\x18\x03 \x01(\x0b\x32(.spaceone.api.monitoring.v1.AlertOptions\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"B\n\x19ProjectAlertConfigRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"S\n\x1cGetProjectAlertConfigRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x8a\x01\n\x17ProjectAlertConfigQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x1c\n\x14\x65scalation_policy_id\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xe0\x01\n\x16ProjectAlertConfigInfo\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x39\n\x07options\x18\x02 \x01(\x0b\x32(.spaceone.api.monitoring.v1.AlertOptions\x12P\n\x16\x65scalation_policy_info\x18\x03 \x01(\x0b\x32\x30.spaceone.api.monitoring.v1.EscalationPolicyInfo\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"s\n\x17ProjectAlertConfigsInfo\x12\x43\n\x07results\x18\x01 \x03(\x0b\x32\x32.spaceone.api.monitoring.v1.ProjectAlertConfigInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"f\n\x1bProjectAlertConfigStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xbd\x08\n\x12ProjectAlertConfig\x12\xa7\x01\n\x06\x63reate\x12;.spaceone.api.monitoring.v1.CreateProjectAlertConfigRequest\x1a\x32.spaceone.api.monitoring.v1.ProjectAlertConfigInfo\",\x82\xd3\xe4\x93\x02&\"$/monitoring/v1/project-alert-configs\x12\xc0\x01\n\x06update\x12;.spaceone.api.monitoring.v1.UpdateProjectAlertConfigRequest\x1a\x32.spaceone.api.monitoring.v1.ProjectAlertConfigInfo\"E\x82\xd3\xe4\x93\x02?\x1a=/monitoring/v1/project-alert-config/{project_alert_config_id}\x12\x9e\x01\n\x06\x64\x65lete\x12\x35.spaceone.api.monitoring.v1.ProjectAlertConfigRequest\x1a\x16.google.protobuf.Empty\"E\x82\xd3\xe4\x93\x02?*=/monitoring/v1/project-alert-config/{project_alert_config_id}\x12\xba\x01\n\x03get\x12\x38.spaceone.api.monitoring.v1.GetProjectAlertConfigRequest\x1a\x32.spaceone.api.monitoring.v1.ProjectAlertConfigInfo\"E\x82\xd3\xe4\x93\x02?\x12=/monitoring/v1/project-alert-config/{project_alert_config_id}\x12\xcd\x01\n\x04list\x12\x33.spaceone.api.monitoring.v1.ProjectAlertConfigQuery\x1a\x33.spaceone.api.monitoring.v1.ProjectAlertConfigsInfo\"[\x82\xd3\xe4\x93\x02U\x12$/monitoring/v1/project-alert-configsZ-\"+/monitoring/v1/project-alert-configs/search\x12\x8b\x01\n\x04stat\x12\x37.spaceone.api.monitoring.v1.ProjectAlertConfigStatQuery\x1a\x17.google.protobuf.Struct\"1\x82\xd3\xe4\x93\x02+\")/monitoring/v1/project-alert-configs/statb\x06proto3')



_ALERTOPTIONS = DESCRIPTOR.message_types_by_name['AlertOptions']
_CREATEPROJECTALERTCONFIGREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectAlertConfigRequest']
_UPDATEPROJECTALERTCONFIGREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectAlertConfigRequest']
_PROJECTALERTCONFIGREQUEST = DESCRIPTOR.message_types_by_name['ProjectAlertConfigRequest']
_GETPROJECTALERTCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetProjectAlertConfigRequest']
_PROJECTALERTCONFIGQUERY = DESCRIPTOR.message_types_by_name['ProjectAlertConfigQuery']
_PROJECTALERTCONFIGINFO = DESCRIPTOR.message_types_by_name['ProjectAlertConfigInfo']
_PROJECTALERTCONFIGSINFO = DESCRIPTOR.message_types_by_name['ProjectAlertConfigsInfo']
_PROJECTALERTCONFIGSTATQUERY = DESCRIPTOR.message_types_by_name['ProjectAlertConfigStatQuery']
_ALERTOPTIONS_URGENCYOPTION = _ALERTOPTIONS.enum_types_by_name['UrgencyOption']
_ALERTOPTIONS_RECOVERYOPTION = _ALERTOPTIONS.enum_types_by_name['RecoveryOption']
AlertOptions = _reflection.GeneratedProtocolMessageType('AlertOptions', (_message.Message,), {
  'DESCRIPTOR' : _ALERTOPTIONS,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.AlertOptions)
  })
_sym_db.RegisterMessage(AlertOptions)

CreateProjectAlertConfigRequest = _reflection.GeneratedProtocolMessageType('CreateProjectAlertConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTALERTCONFIGREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.CreateProjectAlertConfigRequest)
  })
_sym_db.RegisterMessage(CreateProjectAlertConfigRequest)

UpdateProjectAlertConfigRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectAlertConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTALERTCONFIGREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.UpdateProjectAlertConfigRequest)
  })
_sym_db.RegisterMessage(UpdateProjectAlertConfigRequest)

ProjectAlertConfigRequest = _reflection.GeneratedProtocolMessageType('ProjectAlertConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTALERTCONFIGREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ProjectAlertConfigRequest)
  })
_sym_db.RegisterMessage(ProjectAlertConfigRequest)

GetProjectAlertConfigRequest = _reflection.GeneratedProtocolMessageType('GetProjectAlertConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTALERTCONFIGREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.GetProjectAlertConfigRequest)
  })
_sym_db.RegisterMessage(GetProjectAlertConfigRequest)

ProjectAlertConfigQuery = _reflection.GeneratedProtocolMessageType('ProjectAlertConfigQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTALERTCONFIGQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ProjectAlertConfigQuery)
  })
_sym_db.RegisterMessage(ProjectAlertConfigQuery)

ProjectAlertConfigInfo = _reflection.GeneratedProtocolMessageType('ProjectAlertConfigInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTALERTCONFIGINFO,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ProjectAlertConfigInfo)
  })
_sym_db.RegisterMessage(ProjectAlertConfigInfo)

ProjectAlertConfigsInfo = _reflection.GeneratedProtocolMessageType('ProjectAlertConfigsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTALERTCONFIGSINFO,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ProjectAlertConfigsInfo)
  })
_sym_db.RegisterMessage(ProjectAlertConfigsInfo)

ProjectAlertConfigStatQuery = _reflection.GeneratedProtocolMessageType('ProjectAlertConfigStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTALERTCONFIGSTATQUERY,
  '__module__' : 'spaceone.api.monitoring.v1.project_alert_config_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.ProjectAlertConfigStatQuery)
  })
_sym_db.RegisterMessage(ProjectAlertConfigStatQuery)

_PROJECTALERTCONFIG = DESCRIPTOR.services_by_name['ProjectAlertConfig']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECTALERTCONFIG.methods_by_name['create']._options = None
  _PROJECTALERTCONFIG.methods_by_name['create']._serialized_options = b'\202\323\344\223\002&\"$/monitoring/v1/project-alert-configs'
  _PROJECTALERTCONFIG.methods_by_name['update']._options = None
  _PROJECTALERTCONFIG.methods_by_name['update']._serialized_options = b'\202\323\344\223\002?\032=/monitoring/v1/project-alert-config/{project_alert_config_id}'
  _PROJECTALERTCONFIG.methods_by_name['delete']._options = None
  _PROJECTALERTCONFIG.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002?*=/monitoring/v1/project-alert-config/{project_alert_config_id}'
  _PROJECTALERTCONFIG.methods_by_name['get']._options = None
  _PROJECTALERTCONFIG.methods_by_name['get']._serialized_options = b'\202\323\344\223\002?\022=/monitoring/v1/project-alert-config/{project_alert_config_id}'
  _PROJECTALERTCONFIG.methods_by_name['list']._options = None
  _PROJECTALERTCONFIG.methods_by_name['list']._serialized_options = b'\202\323\344\223\002U\022$/monitoring/v1/project-alert-configsZ-\"+/monitoring/v1/project-alert-configs/search'
  _PROJECTALERTCONFIG.methods_by_name['stat']._options = None
  _PROJECTALERTCONFIG.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002+\")/monitoring/v1/project-alert-configs/stat'
  _ALERTOPTIONS._serialized_start=261
  _ALERTOPTIONS._serialized_end=559
  _ALERTOPTIONS_URGENCYOPTION._serialized_start=443
  _ALERTOPTIONS_URGENCYOPTION._serialized_end=500
  _ALERTOPTIONS_RECOVERYOPTION._serialized_start=502
  _ALERTOPTIONS_RECOVERYOPTION._serialized_end=559
  _CREATEPROJECTALERTCONFIGREQUEST._serialized_start=562
  _CREATEPROJECTALERTCONFIGREQUEST._serialized_end=723
  _UPDATEPROJECTALERTCONFIGREQUEST._serialized_start=726
  _UPDATEPROJECTALERTCONFIGREQUEST._serialized_end=887
  _PROJECTALERTCONFIGREQUEST._serialized_start=889
  _PROJECTALERTCONFIGREQUEST._serialized_end=955
  _GETPROJECTALERTCONFIGREQUEST._serialized_start=957
  _GETPROJECTALERTCONFIGREQUEST._serialized_end=1040
  _PROJECTALERTCONFIGQUERY._serialized_start=1043
  _PROJECTALERTCONFIGQUERY._serialized_end=1181
  _PROJECTALERTCONFIGINFO._serialized_start=1184
  _PROJECTALERTCONFIGINFO._serialized_end=1408
  _PROJECTALERTCONFIGSINFO._serialized_start=1410
  _PROJECTALERTCONFIGSINFO._serialized_end=1525
  _PROJECTALERTCONFIGSTATQUERY._serialized_start=1527
  _PROJECTALERTCONFIGSTATQUERY._serialized_end=1629
  _PROJECTALERTCONFIG._serialized_start=1632
  _PROJECTALERTCONFIG._serialized_end=2717
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/provider.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/identity/v1/provider.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xf4\x01\n\x15\x43reateProviderRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x08template\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"\xf4\x01\n\x15UpdateProviderRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x08template\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x07 \x01(\t\"6\n\x0fProviderRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"G\n\x12GetProviderRequest\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04only\x18\x02 \x03(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"n\n\rProviderQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xec\x01\n\x0cProviderInfo\x12\x10\n\x08provider\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x08template\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_at\x18\x07 \x01(\t\"]\n\rProvidersInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.identity.v1.ProviderInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\\\n\x11ProviderStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xb3\x06\n\x08Provider\x12\x81\x01\n\x06\x63reate\x12/.spaceone.api.identity.v1.CreateProviderRequest\x1a&.spaceone.api.identity.v1.ProviderInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/identity/v1/providers\x12\x8e\x01\n\x06update\x12/.spaceone.api.identity.v1.UpdateProviderRequest\x1a&.spaceone.api.identity.v1.ProviderInfo\"+\x82\xd3\xe4\x93\x02%\x1a#/identity/v1/provider/{provider_id}\x12x\n\x06\x64\x65lete\x12).spaceone.api.identity.v1.ProviderRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%*#/identity/v1/provider/{provider_id}\x12\x88\x01\n\x03get\x12,.spaceone.api.identity.v1.GetProviderRequest\x1a&.spaceone.api.identity.v1.ProviderInfo\"+\x82\xd3\xe4\x93\x02%\x12#/identity/v1/provider/{provider_id}\x12\x99\x01\n\x04list\x12\'.spaceone.api.identity.v1.ProviderQuery\x1a\'.spaceone.api.identity.v1.ProvidersInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/identity/v1/providersZ\x1f\"\x1d/identity/v1/providers/search\x12q\n\x04stat\x12+.spaceone.api.identity.v1.ProviderStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/identity/v1/providers/statb\x06proto3')



_CREATEPROVIDERREQUEST = DESCRIPTOR.message_types_by_name['CreateProviderRequest']
_UPDATEPROVIDERREQUEST = DESCRIPTOR.message_types_by_name['UpdateProviderRequest']
_PROVIDERREQUEST = DESCRIPTOR.message_types_by_name['ProviderRequest']
_GETPROVIDERREQUEST = DESCRIPTOR.message_types_by_name['GetProviderRequest']
_PROVIDERQUERY = DESCRIPTOR.message_types_by_name['ProviderQuery']
_PROVIDERINFO = DESCRIPTOR.message_types_by_name['ProviderInfo']
_PROVIDERSINFO = DESCRIPTOR.message_types_by_name['ProvidersInfo']
_PROVIDERSTATQUERY = DESCRIPTOR.message_types_by_name['ProviderStatQuery']
CreateProviderRequest = _reflection.GeneratedProtocolMessageType('CreateProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROVIDERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateProviderRequest)
  })
_sym_db.RegisterMessage(CreateProviderRequest)

UpdateProviderRequest = _reflection.GeneratedProtocolMessageType('UpdateProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROVIDERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateProviderRequest)
  })
_sym_db.RegisterMessage(UpdateProviderRequest)

ProviderRequest = _reflection.GeneratedProtocolMessageType('ProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProviderRequest)
  })
_sym_db.RegisterMessage(ProviderRequest)

GetProviderRequest = _reflection.GeneratedProtocolMessageType('GetProviderRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROVIDERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetProviderRequest)
  })
_sym_db.RegisterMessage(GetProviderRequest)

ProviderQuery = _reflection.GeneratedProtocolMessageType('ProviderQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERQUERY,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProviderQuery)
  })
_sym_db.RegisterMessage(ProviderQuery)

ProviderInfo = _reflection.GeneratedProtocolMessageType('ProviderInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERINFO,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProviderInfo)
  })
_sym_db.RegisterMessage(ProviderInfo)

ProvidersInfo = _reflection.GeneratedProtocolMessageType('ProvidersInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERSINFO,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProvidersInfo)
  })
_sym_db.RegisterMessage(ProvidersInfo)

ProviderStatQuery = _reflection.GeneratedProtocolMessageType('ProviderStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDERSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.provider_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProviderStatQuery)
  })
_sym_db.RegisterMessage(ProviderStatQuery)

_PROVIDER = DESCRIPTOR.services_by_name['Provider']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROVIDER.methods_by_name['create']._options = None
  _PROVIDER.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\030\"\026/identity/v1/providers'
  _PROVIDER.methods_by_name['update']._options = None
  _PROVIDER.methods_by_name['update']._serialized_options = b'\202\323\344\223\002%\032#/identity/v1/provider/{provider_id}'
  _PROVIDER.methods_by_name['delete']._options = None
  _PROVIDER.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002%*#/identity/v1/provider/{provider_id}'
  _PROVIDER.methods_by_name['get']._options = None
  _PROVIDER.methods_by_name['get']._serialized_options = b'\202\323\344\223\002%\022#/identity/v1/provider/{provider_id}'
  _PROVIDER.methods_by_name['list']._options = None
  _PROVIDER.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/identity/v1/providersZ\037\"\035/identity/v1/providers/search'
  _PROVIDER.methods_by_name['stat']._options = None
  _PROVIDER.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/identity/v1/providers/stat'
  _CREATEPROVIDERREQUEST._serialized_start=193
  _CREATEPROVIDERREQUEST._serialized_end=437
  _UPDATEPROVIDERREQUEST._serialized_start=440
  _UPDATEPROVIDERREQUEST._serialized_end=684
  _PROVIDERREQUEST._serialized_start=686
  _PROVIDERREQUEST._serialized_end=740
  _GETPROVIDERREQUEST._serialized_start=742
  _GETPROVIDERREQUEST._serialized_end=813
  _PROVIDERQUERY._serialized_start=815
  _PROVIDERQUERY._serialized_end=925
  _PROVIDERINFO._serialized_start=928
  _PROVIDERINFO._serialized_end=1164
  _PROVIDERSINFO._serialized_start=1166
  _PROVIDERSINFO._serialized_end=1259
  _PROVIDERSTATQUERY._serialized_start=1261
  _PROVIDERSTATQUERY._serialized_end=1353
  _PROVIDER._serialized_start=1356
  _PROVIDER._serialized_end=2175
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.plugin.v1 import plugin_pb2 as spaceone_dot_api_dot_plugin_dot_v1_dot_plugin__pb2


class PluginStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get_plugin_endpoint = channel.unary_unary(
                '/spaceone.api.plugin.v1.Plugin/get_plugin_endpoint',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_plugin__pb2.PluginEndpointRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_plugin__pb2.PluginEndpoint.FromString,
                )
        self.notify_failure = channel.unary_unary(
                '/spaceone.api.plugin.v1.Plugin/notify_failure',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_plugin__pb2.PluginFailureRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )


class PluginServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get_plugin_endpoint(self, request, context):
        """
        desc: Gets the `endpoint` of a specific plugin instance. A Plugin returns only a single `endpoint` by determining `labels` and `priority`. If the requested plugin instance is already deployed, the `endpoint` is returned. If not, the `endpoint` is returned after deploying the plugin instance.
        request_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "version": "1.2.2"
        }
        response_example: >-
        {
        "endpoint": "grpc://endpoint-url:50051"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def notify_failure(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PluginServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get_plugin_endpoint': grpc.unary_unary_rpc_method_handler(
                    servicer.get_plugin_endpoint,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_plugin__pb2.PluginEndpointRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_plugin__pb2.PluginEndpoint.SerializeToString,
            ),
            'notify_failure': grpc.unary_unary_rpc_method_handler(
                    servicer.notify_failure,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_plugin__pb2.PluginFailureRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.plugin.v1.Plugin', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Plugin(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get_plugin_endpoint(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Plugin/get_plugin_endpoint',
            spaceone_dot_api_dot_plugin_dot_v1_dot_plugin__pb2.PluginEndpointRequest.SerializeToString,
            spaceone_dot_api_dot_plugin_dot_v1_dot_plugin__pb2.PluginEndpoint.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def notify_failure(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Plugin/notify_failure',
            spaceone_dot_api_dot_plugin_dot_v1_dot_plugin__pb2.PluginFailureRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/repository/v1/plugin.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.repository.v1 import repository_pb2 as spaceone_dot_api_dot_repository_dot_v1_dot_repository__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/repository/v1/plugin.proto\x12\x1aspaceone.api.repository.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a+spaceone/api/repository/v1/repository.proto\"\xa5\x03\n\x13\x43reatePluginRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0cservice_type\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\x45\n\rregistry_type\x18\x05 \x01(\x0e\x32..spaceone.api.repository.v1.PublicRegistryType\x12\x30\n\x0fregistry_config\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08template\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\r \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nproject_id\x18\x15 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\"\xf4\x01\n\x13UpdatePluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12+\n\ncapability\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08template\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\r \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"5\n\rPluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"V\n\x17RepositoryPluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x15\n\rrepository_id\x18\x03 \x01(\t\"g\n\x1aGetRepositoryPluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x15\n\rrepository_id\x18\x03 \x01(\t\x12\x0c\n\x04only\x18\x04 \x03(\t\"\xdf\x02\n\x0bPluginQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tplugin_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12<\n\x05state\x18\x04 \x01(\x0e\x32-.spaceone.api.repository.v1.PluginQuery.State\x12\x14\n\x0cservice_type\x18\x05 \x01(\t\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x15\n\rrepository_id\x18\x07 \x01(\t\x12\x11\n\tdomain_id\x18\x08 \x01(\t\x12\x45\n\rregistry_type\x18\t \x01(\x0e\x32..spaceone.api.repository.v1.PublicRegistryType\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"\x9d\x05\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05image\x18\x03 \x01(\t\x12\x14\n\x0cregistry_url\x18\x04 \x01(\t\x12;\n\x05state\x18\x05 \x01(\x0e\x32,.spaceone.api.repository.v1.PluginInfo.State\x12\x14\n\x0cservice_type\x18\x06 \x01(\t\x12\x10\n\x08provider\x18\x07 \x01(\t\x12\x45\n\rregistry_type\x18\x08 \x01(\x0e\x32..spaceone.api.repository.v1.PublicRegistryType\x12\x30\n\x0fregistry_config\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08template\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\r \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x43\n\x0frepository_info\x18\x15 \x01(\x0b\x32*.spaceone.api.repository.v1.RepositoryInfo\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"[\n\x0bPluginsInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.repository.v1.PluginInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"E\n\x0cVersionsInfo\x12\x0f\n\x07version\x18\x01 \x03(\t\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x12\x0f\n\x07results\x18\x03 \x03(\t\"q\n\x0fPluginStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x15\n\rrepository_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t*\\\n\x12PublicRegistryType\x12\x16\n\x12NONE_REGISTRY_TYPE\x10\x00\x12\x0e\n\nDOCKER_HUB\x10\x01\x12\x12\n\x0e\x41WS_PUBLIC_ECR\x10\x02\x12\n\n\x06HARBOR\x10\x03\x32\x83\n\n\x06Plugin\x12\x83\x01\n\x08register\x12/.spaceone.api.repository.v1.CreatePluginRequest\x1a&.spaceone.api.repository.v1.PluginInfo\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/repository/v1/plugins\x12\x8c\x01\n\x06update\x12/.spaceone.api.repository.v1.UpdatePluginRequest\x1a&.spaceone.api.repository.v1.PluginInfo\")\x82\xd3\xe4\x93\x02#\x1a!/repository/v1/plugin/{plugin_id}\x12z\n\nderegister\x12).spaceone.api.repository.v1.PluginRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/repository/v1/plugin/{plugin_id}\x12\x8d\x01\n\x06\x65nable\x12).spaceone.api.repository.v1.PluginRequest\x1a&.spaceone.api.repository.v1.PluginInfo\"0\x82\xd3\xe4\x93\x02*\x1a(/repository/v1/plugin/{plugin_id}/enable\x12\x8f\x01\n\x07\x64isable\x12).spaceone.api.repository.v1.PluginRequest\x1a&.spaceone.api.repository.v1.PluginInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/repository/v1/plugin/{plugin_id}/disable\x12\xa2\x01\n\x0cget_versions\x12\x33.spaceone.api.repository.v1.RepositoryPluginRequest\x1a(.spaceone.api.repository.v1.VersionsInfo\"3\x82\xd3\xe4\x93\x02-\x12+/repository/v1/plugins/{plugin_id}/versions\x12\x91\x01\n\x03get\x12\x36.spaceone.api.repository.v1.GetRepositoryPluginRequest\x1a&.spaceone.api.repository.v1.PluginInfo\"*\x82\xd3\xe4\x93\x02$\x12\"/repository/v1/plugins/{plugin_id}\x12\x99\x01\n\x04list\x12\'.spaceone.api.repository.v1.PluginQuery\x1a\'.spaceone.api.repository.v1.PluginsInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/repository/v1/pluginsZ\x1f\"\x1d/repository/v1/plugins/search\x12q\n\x04stat\x12+.spaceone.api.repository.v1.PluginStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/repository/v1/plugins/statb\x06proto3')

_PUBLICREGISTRYTYPE = DESCRIPTOR.enum_types_by_name['PublicRegistryType']
PublicRegistryType = enum_type_wrapper.EnumTypeWrapper(_PUBLICREGISTRYTYPE)
NONE_REGISTRY_TYPE = 0
DOCKER_HUB = 1
AWS_PUBLIC_ECR = 2
HARBOR = 3


_CREATEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['CreatePluginRequest']
_UPDATEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdatePluginRequest']
_PLUGINREQUEST = DESCRIPTOR.message_types_by_name['PluginRequest']
_REPOSITORYPLUGINREQUEST = DESCRIPTOR.message_types_by_name['RepositoryPluginRequest']
_GETREPOSITORYPLUGINREQUEST = DESCRIPTOR.message_types_by_name['GetRepositoryPluginRequest']
_PLUGINQUERY = DESCRIPTOR.message_types_by_name['PluginQuery']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_PLUGINSINFO = DESCRIPTOR.message_types_by_name['PluginsInfo']
_VERSIONSINFO = DESCRIPTOR.message_types_by_name['VersionsInfo']
_PLUGINSTATQUERY = DESCRIPTOR.message_types_by_name['PluginStatQuery']
_PLUGINQUERY_STATE = _PLUGINQUERY.enum_types_by_name['State']
_PLUGININFO_STATE = _PLUGININFO.enum_types_by_name['State']
CreatePluginRequest = _reflection.GeneratedProtocolMessageType('CreatePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPLUGINREQUEST,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.CreatePluginRequest)
  })
_sym_db.RegisterMessage(CreatePluginRequest)

UpdatePluginRequest = _reflection.GeneratedProtocolMessageType('UpdatePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPLUGINREQUEST,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.UpdatePluginRequest)
  })
_sym_db.RegisterMessage(UpdatePluginRequest)

PluginRequest = _reflection.GeneratedProtocolMessageType('PluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINREQUEST,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PluginRequest)
  })
_sym_db.RegisterMessage(PluginRequest)

RepositoryPluginRequest = _reflection.GeneratedProtocolMessageType('RepositoryPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _REPOSITORYPLUGINREQUEST,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.RepositoryPluginRequest)
  })
_sym_db.RegisterMessage(RepositoryPluginRequest)

GetRepositoryPluginRequest = _reflection.GeneratedProtocolMessageType('GetRepositoryPluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETREPOSITORYPLUGINREQUEST,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.GetRepositoryPluginRequest)
  })
_sym_db.RegisterMessage(GetRepositoryPluginRequest)

PluginQuery = _reflection.GeneratedProtocolMessageType('PluginQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINQUERY,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PluginQuery)
  })
_sym_db.RegisterMessage(PluginQuery)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

PluginsInfo = _reflection.GeneratedProtocolMessageType('PluginsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINSINFO,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PluginsInfo)
  })
_sym_db.RegisterMessage(PluginsInfo)

VersionsInfo = _reflection.GeneratedProtocolMessageType('VersionsInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONSINFO,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.VersionsInfo)
  })
_sym_db.RegisterMessage(VersionsInfo)

PluginStatQuery = _reflection.GeneratedProtocolMessageType('PluginStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINSTATQUERY,
  '__module__' : 'spaceone.api.repository.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.repository.v1.PluginStatQuery)
  })
_sym_db.RegisterMessage(PluginStatQuery)

_PLUGIN = DESCRIPTOR.services_by_name['Plugin']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLUGIN.methods_by_name['register']._options = None
  _PLUGIN.methods_by_name['register']._serialized_options = b'\202\323\344\223\002\030\"\026/repository/v1/plugins'
  _PLUGIN.methods_by_name['update']._options = None
  _PLUGIN.methods_by_name['update']._serialized_options = b'\202\323\344\223\002#\032!/repository/v1/plugin/{plugin_id}'
  _PLUGIN.methods_by_name['deregister']._options = None
  _PLUGIN.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\002#*!/repository/v1/plugin/{plugin_id}'
  _PLUGIN.methods_by_name['enable']._options = None
  _PLUGIN.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002*\032(/repository/v1/plugin/{plugin_id}/enable'
  _PLUGIN.methods_by_name['disable']._options = None
  _PLUGIN.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002+\032)/repository/v1/plugin/{plugin_id}/disable'
  _PLUGIN.methods_by_name['get_versions']._options = None
  _PLUGIN.methods_by_name['get_versions']._serialized_options = b'\202\323\344\223\002-\022+/repository/v1/plugins/{plugin_id}/versions'
  _PLUGIN.methods_by_name['get']._options = None
  _PLUGIN.methods_by_name['get']._serialized_options = b'\202\323\344\223\002$\022\"/repository/v1/plugins/{plugin_id}'
  _PLUGIN.methods_by_name['list']._options = None
  _PLUGIN.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/repository/v1/pluginsZ\037\"\035/repository/v1/plugins/search'
  _PLUGIN.methods_by_name['stat']._options = None
  _PLUGIN.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/repository/v1/plugins/stat'
  _PUBLICREGISTRYTYPE._serialized_start=2463
  _PUBLICREGISTRYTYPE._serialized_end=2555
  _CREATEPLUGINREQUEST._serialized_start=240
  _CREATEPLUGINREQUEST._serialized_end=661
  _UPDATEPLUGINREQUEST._serialized_start=664
  _UPDATEPLUGINREQUEST._serialized_end=908
  _PLUGINREQUEST._serialized_start=910
  _PLUGINREQUEST._serialized_end=963
  _REPOSITORYPLUGINREQUEST._serialized_start=965
  _REPOSITORYPLUGINREQUEST._serialized_end=1051
  _GETREPOSITORYPLUGINREQUEST._serialized_start=1053
  _GETREPOSITORYPLUGINREQUEST._serialized_end=1156
  _PLUGINQUERY._serialized_start=1159
  _PLUGINQUERY._serialized_end=1510
  _PLUGINQUERY_STATE._serialized_start=1466
  _PLUGINQUERY_STATE._serialized_end=1510
  _PLUGININFO._serialized_start=1513
  _PLUGININFO._serialized_end=2182
  _PLUGININFO_STATE._serialized_start=1466
  _PLUGININFO_STATE._serialized_end=1510
  _PLUGINSINFO._serialized_start=2184
  _PLUGINSINFO._serialized_end=2275
  _VERSIONSINFO._serialized_start=2277
  _VERSIONSINFO._serialized_end=2346
  _PLUGINSTATQUERY._serialized_start=2348
  _PLUGINSTATQUERY._serialized_end=2461
  _PLUGIN._serialized_start=2558
  _PLUGIN._serialized_end=3841
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/cost_analysis/v1/job.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"/\n\nJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"@\n\rGetJobRequest\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x91\x02\n\x08JobQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0e\n\x06job_id\x18\x02 \x01(\t\x12>\n\x06status\x18\x03 \x01(\x0e\x32..spaceone.api.cost_analysis.v1.JobQuery.Status\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"^\n\x06Status\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x0b\n\x07\x46\x41ILURE\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08\x43\x41NCELED\x10\x05\"R\n\x0b\x43hangedInfo\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\x12\'\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xdf\x03\n\x07JobInfo\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12=\n\x06status\x18\x02 \x01(\x0e\x32-.spaceone.api.cost_analysis.v1.JobInfo.Status\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\nerror_code\x18\x04 \x01(\t\x12\x15\n\rerror_message\x18\x05 \x01(\t\x12\x13\n\x0btotal_tasks\x18\x06 \x01(\x05\x12\x16\n\x0eremained_tasks\x18\x07 \x01(\x05\x12\x16\n\x0e\x64\x61ta_source_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nupdated_at\x18\x16 \x01(\t\x12\x13\n\x0b\x66inished_at\x18\x17 \x01(\t\x12;\n\x07\x63hanged\x18\x18 \x03(\x0b\x32*.spaceone.api.cost_analysis.v1.ChangedInfo\"^\n\x06Status\x12\x0e\n\nSCOPE_NONE\x10\x00\x12\x0f\n\x0bIN_PROGRESS\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x0b\n\x07\x46\x41ILURE\x10\x03\x12\x0b\n\x07TIMEOUT\x10\x04\x12\x0c\n\x08\x43\x41NCELED\x10\x05\"X\n\x08JobsInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.cost_analysis.v1.JobInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"W\n\x0cJobStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa7\x04\n\x03Job\x12\x8a\x01\n\x06\x63\x61ncel\x12).spaceone.api.cost_analysis.v1.JobRequest\x1a&.spaceone.api.cost_analysis.v1.JobInfo\"-\x82\xd3\xe4\x93\x02\'\"%/cost-analysis/v1/job/{job_id}/cancel\x12\x83\x01\n\x03get\x12,.spaceone.api.cost_analysis.v1.GetJobRequest\x1a&.spaceone.api.cost_analysis.v1.JobInfo\"&\x82\xd3\xe4\x93\x02 \x12\x1e/cost-analysis/v1/job/{job_id}\x12\x99\x01\n\x04list\x12\'.spaceone.api.cost_analysis.v1.JobQuery\x1a\'.spaceone.api.cost_analysis.v1.JobsInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/cost-analysis/v1/jobsZ\x1f\"\x1d/cost-analysis/v1/jobs/search\x12q\n\x04stat\x12+.spaceone.api.cost_analysis.v1.JobStatQuery\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/cost-analysis/v1/jobs/statb\x06proto3')



_JOBREQUEST = DESCRIPTOR.message_types_by_name['JobRequest']
_GETJOBREQUEST = DESCRIPTOR.message_types_by_name['GetJobRequest']
_JOBQUERY = DESCRIPTOR.message_types_by_name['JobQuery']
_CHANGEDINFO = DESCRIPTOR.message_types_by_name['ChangedInfo']
_JOBINFO = DESCRIPTOR.message_types_by_name['JobInfo']
_JOBSINFO = DESCRIPTOR.message_types_by_name['JobsInfo']
_JOBSTATQUERY = DESCRIPTOR.message_types_by_name['JobStatQuery']
_JOBQUERY_STATUS = _JOBQUERY.enum_types_by_name['Status']
_JOBINFO_STATUS = _JOBINFO.enum_types_by_name['Status']
JobRequest = _reflection.GeneratedProtocolMessageType('JobRequest', (_message.Message,), {
  'DESCRIPTOR' : _JOBREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobRequest)
  })
_sym_db.RegisterMessage(JobRequest)

GetJobRequest = _reflection.GeneratedProtocolMessageType('GetJobRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETJOBREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetJobRequest)
  })
_sym_db.RegisterMessage(GetJobRequest)

JobQuery = _reflection.GeneratedProtocolMessageType('JobQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobQuery)
  })
_sym_db.RegisterMessage(JobQuery)

ChangedInfo = _reflection.GeneratedProtocolMessageType('ChangedInfo', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEDINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.ChangedInfo)
  })
_sym_db.RegisterMessage(ChangedInfo)

JobInfo = _reflection.GeneratedProtocolMessageType('JobInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobInfo)
  })
_sym_db.RegisterMessage(JobInfo)

JobsInfo = _reflection.GeneratedProtocolMessageType('JobsInfo', (_message.Message,), {
  'DESCRIPTOR' : _JOBSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobsInfo)
  })
_sym_db.RegisterMessage(JobsInfo)

JobStatQuery = _reflection.GeneratedProtocolMessageType('JobStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _JOBSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.JobStatQuery)
  })
_sym_db.RegisterMessage(JobStatQuery)

_JOB = DESCRIPTOR.services_by_name['Job']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _JOB.methods_by_name['cancel']._options = None
  _JOB.methods_by_name['cancel']._serialized_options = b'\202\323\344\223\002\'\"%/cost-analysis/v1/job/{job_id}/cancel'
  _JOB.methods_by_name['get']._options = None
  _JOB.methods_by_name['get']._serialized_options = b'\202\323\344\223\002 \022\036/cost-analysis/v1/job/{job_id}'
  _JOB.methods_by_name['list']._options = None
  _JOB.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/cost-analysis/v1/jobsZ\037\"\035/cost-analysis/v1/jobs/search'
  _JOB.methods_by_name['stat']._options = None
  _JOB.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/cost-analysis/v1/jobs/stat'
  _JOBREQUEST._serialized_start=168
  _JOBREQUEST._serialized_end=215
  _GETJOBREQUEST._serialized_start=217
  _GETJOBREQUEST._serialized_end=281
  _JOBQUERY._serialized_start=284
  _JOBQUERY._serialized_end=557
  _JOBQUERY_STATUS._serialized_start=463
  _JOBQUERY_STATUS._serialized_end=557
  _CHANGEDINFO._serialized_start=559
  _CHANGEDINFO._serialized_end=641
  _JOBINFO._serialized_start=644
  _JOBINFO._serialized_end=1123
  _JOBINFO_STATUS._serialized_start=463
  _JOBINFO_STATUS._serialized_end=557
  _JOBSINFO._serialized_start=1125
  _JOBSINFO._serialized_end=1213
  _JOBSTATQUERY._serialized_start=1215
  _JOBSTATQUERY._serialized_end=1302
  _JOB._serialized_start=1305
  _JOB._serialized_end=1856
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/project.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.identity.v1 import role_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_role__pb2
from spaceone.api.identity.v1 import project_group_pb2 as spaceone_dot_api_dot_identity_dot_v1_dot_project__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/identity/v1/project.proto\x12\x18spaceone.api.identity.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a#spaceone/api/identity/v1/role.proto\x1a,spaceone/api/identity/v1/project_group.proto\"x\n\x14\x43reateProjectRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x18\n\x10project_group_id\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xa3\x01\n\x14UpdateProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x18\n\x10project_group_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x05 \x01(\t\x12\x15\n\rprofit_margin\x18\x06 \x01(\t\"7\n\x0eProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"H\n\x11GetProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xf6\x01\n\x0cProjectQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x18\n\x10project_group_id\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x12\n\ngroup_name\x18\x07 \x01(\t\x12\x15\n\rprofit_margin\x18\x08 \x01(\t\x12\r\n\x05start\x18\t \x01(\t\x12\x0b\n\x03\x65nd\x18\n \x01(\t\x12\x13\n\x0bproject_ids\x18\x0b \x03(\t\"\xf0\x01\n\x0bProjectInfo\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x46\n\x12project_group_info\x18\x04 \x01(\x0b\x32*.spaceone.api.identity.v1.ProjectGroupInfo\x12\x15\n\rprofit_margin\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_by\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\"[\n\x0cProjectsInfo\x12\x36\n\x07results\x18\x01 \x03(\x0b\x32%.spaceone.api.identity.v1.ProjectInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xcf\x01\n\x17\x41\x64\x64ProjectMemberRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x0f\n\x07role_id\x18\x03 \x01(\t\x12*\n\x06labels\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x18\n\x10is_external_user\x18\x07 \x01(\x08\"\xa7\x01\n\x1aModifyProjectMemberRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12*\n\x06labels\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x05 \x01(\t\"T\n\x1aRemoveProjectMemberRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"\xa8\x01\n\x12ProjectMemberQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0f\n\x07user_id\x18\x03 \x01(\t\x12\x0f\n\x07role_id\x18\x04 \x01(\t\x12\x1d\n\x15include_parent_member\x18\x05 \x01(\x08\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"\x93\x03\n\x16ProjectRoleBindingInfo\x12\x17\n\x0frole_binding_id\x18\x01 \x01(\t\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x35\n\trole_info\x18\x04 \x01(\x0b\x32\".spaceone.api.identity.v1.RoleInfo\x12;\n\x0cproject_info\x18\x05 \x01(\x0b\x32%.spaceone.api.identity.v1.ProjectInfo\x12\x46\n\x12project_group_info\x18\x06 \x01(\x0b\x32*.spaceone.api.identity.v1.ProjectGroupInfo\x12*\n\x06labels\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\"q\n\x17ProjectRoleBindingsInfo\x12\x41\n\x07results\x18\x01 \x03(\x0b\x32\x30.spaceone.api.identity.v1.ProjectRoleBindingInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"[\n\x10ProjectStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\x8f\x14\n\x07Project\x12~\n\x06\x63reate\x12..spaceone.api.identity.v1.CreateProjectRequest\x1a%.spaceone.api.identity.v1.ProjectInfo\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x15/identity/v1/projects\x12\x8a\x01\n\x06update\x12..spaceone.api.identity.v1.UpdateProjectRequest\x1a%.spaceone.api.identity.v1.ProjectInfo\")\x82\xd3\xe4\x93\x02#\x1a!/identity/v1/project/{project_id}\x12\xa0\x01\n\x14update_profit_margin\x12..spaceone.api.identity.v1.UpdateProjectRequest\x1a%.spaceone.api.identity.v1.ProjectInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/identity/v1/project/update-profit-margin\x12u\n\x06\x64\x65lete\x12(.spaceone.api.identity.v1.ProjectRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/identity/v1/project/{project_id}\x12\x84\x01\n\x03get\x12+.spaceone.api.identity.v1.GetProjectRequest\x1a%.spaceone.api.identity.v1.ProjectInfo\")\x82\xd3\xe4\x93\x02#\x12!/identity/v1/project/{project_id}\x12\x95\x01\n\x04list\x12&.spaceone.api.identity.v1.ProjectQuery\x1a&.spaceone.api.identity.v1.ProjectsInfo\"=\x82\xd3\xe4\x93\x02\x37\x12\x15/identity/v1/projectsZ\x1e\"\x1c/identity/v1/projects/search\x12o\n\x04stat\x12*.spaceone.api.identity.v1.ProjectStatQuery\x1a\x17.google.protobuf.Struct\"\"\x82\xd3\xe4\x93\x02\x1c\"\x1a/identity/v1/projects/stat\x12\xa4\x01\n\nadd_member\x12\x31.spaceone.api.identity.v1.AddProjectMemberRequest\x1a\x30.spaceone.api.identity.v1.ProjectRoleBindingInfo\"1\x82\xd3\xe4\x93\x02+\")/identity/v1/project/{project_id}/members\x12\xb3\x01\n\rmodify_member\x12\x34.spaceone.api.identity.v1.ModifyProjectMemberRequest\x1a\x30.spaceone.api.identity.v1.ProjectRoleBindingInfo\":\x82\xd3\xe4\x93\x02\x34\x1a\x32/identity/v1/project/{project_id}/member/{user_id}\x12\x99\x01\n\rremove_member\x12\x34.spaceone.api.identity.v1.RemoveProjectMemberRequest\x1a\x16.google.protobuf.Empty\":\x82\xd3\xe4\x93\x02\x34*2/identity/v1/project/{project_id}/member/{user_id}\x12\xd6\x01\n\x0clist_members\x12,.spaceone.api.identity.v1.ProjectMemberQuery\x1a\x31.spaceone.api.identity.v1.ProjectRoleBindingsInfo\"e\x82\xd3\xe4\x93\x02_\x12)/identity/v1/project/{project_id}/membersZ2\"0/identity/v1/project/{project_id}/members/search\x12\xda\x01\n\x1alist_profit_margin_history\x12&.spaceone.api.identity.v1.ProjectQuery\x1a&.spaceone.api.identity.v1.ProjectsInfo\"l\x82\xd3\xe4\x93\x02\x66\x12//identity/v1/project/profit-margin-history/listZ3\"1/identity/v1/project/profit-margin-history/search\x12\xa7\x01\n\x1c\x63reate_profit_margin_history\x12%.spaceone.api.identity.v1.ProjectInfo\x1a%.spaceone.api.identity.v1.ProjectInfo\"9\x82\xd3\xe4\x93\x02\x33\"1/identity/v1/project/profit-margin-history/create\x12\xa8\x01\n\x1clatest_profit_margin_history\x12&.spaceone.api.identity.v1.ProjectQuery\x1a%.spaceone.api.identity.v1.ProjectInfo\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/identity/v1/project/profit-margin-history/latest\x12\x9a\x01\n\x1astat_profit_margin_history\x12*.spaceone.api.identity.v1.ProjectStatQuery\x1a\x17.google.protobuf.Struct\"7\x82\xd3\xe4\x93\x02\x31\"//identity/v1/project/profit-margin-history/stat\x12\xab\x01\n\x1dmonthly_profit_margin_history\x12&.spaceone.api.identity.v1.ProjectQuery\x1a&.spaceone.api.identity.v1.ProjectsInfo\":\x82\xd3\xe4\x93\x02\x34\x12\x32/identity/v1/project/profit-margin-history/monthlyb\x06proto3')



_CREATEPROJECTREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectRequest']
_UPDATEPROJECTREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectRequest']
_PROJECTREQUEST = DESCRIPTOR.message_types_by_name['ProjectRequest']
_GETPROJECTREQUEST = DESCRIPTOR.message_types_by_name['GetProjectRequest']
_PROJECTQUERY = DESCRIPTOR.message_types_by_name['ProjectQuery']
_PROJECTINFO = DESCRIPTOR.message_types_by_name['ProjectInfo']
_PROJECTSINFO = DESCRIPTOR.message_types_by_name['ProjectsInfo']
_ADDPROJECTMEMBERREQUEST = DESCRIPTOR.message_types_by_name['AddProjectMemberRequest']
_MODIFYPROJECTMEMBERREQUEST = DESCRIPTOR.message_types_by_name['ModifyProjectMemberRequest']
_REMOVEPROJECTMEMBERREQUEST = DESCRIPTOR.message_types_by_name['RemoveProjectMemberRequest']
_PROJECTMEMBERQUERY = DESCRIPTOR.message_types_by_name['ProjectMemberQuery']
_PROJECTROLEBINDINGINFO = DESCRIPTOR.message_types_by_name['ProjectRoleBindingInfo']
_PROJECTROLEBINDINGSINFO = DESCRIPTOR.message_types_by_name['ProjectRoleBindingsInfo']
_PROJECTSTATQUERY = DESCRIPTOR.message_types_by_name['ProjectStatQuery']
CreateProjectRequest = _reflection.GeneratedProtocolMessageType('CreateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.CreateProjectRequest)
  })
_sym_db.RegisterMessage(CreateProjectRequest)

UpdateProjectRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.UpdateProjectRequest)
  })
_sym_db.RegisterMessage(UpdateProjectRequest)

ProjectRequest = _reflection.GeneratedProtocolMessageType('ProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectRequest)
  })
_sym_db.RegisterMessage(ProjectRequest)

GetProjectRequest = _reflection.GeneratedProtocolMessageType('GetProjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.GetProjectRequest)
  })
_sym_db.RegisterMessage(GetProjectRequest)

ProjectQuery = _reflection.GeneratedProtocolMessageType('ProjectQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTQUERY,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectQuery)
  })
_sym_db.RegisterMessage(ProjectQuery)

ProjectInfo = _reflection.GeneratedProtocolMessageType('ProjectInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTINFO,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectInfo)
  })
_sym_db.RegisterMessage(ProjectInfo)

ProjectsInfo = _reflection.GeneratedProtocolMessageType('ProjectsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTSINFO,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectsInfo)
  })
_sym_db.RegisterMessage(ProjectsInfo)

AddProjectMemberRequest = _reflection.GeneratedProtocolMessageType('AddProjectMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDPROJECTMEMBERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.AddProjectMemberRequest)
  })
_sym_db.RegisterMessage(AddProjectMemberRequest)

ModifyProjectMemberRequest = _reflection.GeneratedProtocolMessageType('ModifyProjectMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _MODIFYPROJECTMEMBERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ModifyProjectMemberRequest)
  })
_sym_db.RegisterMessage(ModifyProjectMemberRequest)

RemoveProjectMemberRequest = _reflection.GeneratedProtocolMessageType('RemoveProjectMemberRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEPROJECTMEMBERREQUEST,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.RemoveProjectMemberRequest)
  })
_sym_db.RegisterMessage(RemoveProjectMemberRequest)

ProjectMemberQuery = _reflection.GeneratedProtocolMessageType('ProjectMemberQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTMEMBERQUERY,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectMemberQuery)
  })
_sym_db.RegisterMessage(ProjectMemberQuery)

ProjectRoleBindingInfo = _reflection.GeneratedProtocolMessageType('ProjectRoleBindingInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTROLEBINDINGINFO,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectRoleBindingInfo)
  })
_sym_db.RegisterMessage(ProjectRoleBindingInfo)

ProjectRoleBindingsInfo = _reflection.GeneratedProtocolMessageType('ProjectRoleBindingsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTROLEBINDINGSINFO,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectRoleBindingsInfo)
  })
_sym_db.RegisterMessage(ProjectRoleBindingsInfo)

ProjectStatQuery = _reflection.GeneratedProtocolMessageType('ProjectStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTSTATQUERY,
  '__module__' : 'spaceone.api.identity.v1.project_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.ProjectStatQuery)
  })
_sym_db.RegisterMessage(ProjectStatQuery)

_PROJECT = DESCRIPTOR.services_by_name['Project']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECT.methods_by_name['create']._options = None
  _PROJECT.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\027\"\025/identity/v1/projects'
  _PROJECT.methods_by_name['update']._options = None
  _PROJECT.methods_by_name['update']._serialized_options = b'\202\323\344\223\002#\032!/identity/v1/project/{project_id}'
  _PROJECT.methods_by_name['update_profit_margin']._options = None
  _PROJECT.methods_by_name['update_profit_margin']._serialized_options = b'\202\323\344\223\002+\032)/identity/v1/project/update-profit-margin'
  _PROJECT.methods_by_name['delete']._options = None
  _PROJECT.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002#*!/identity/v1/project/{project_id}'
  _PROJECT.methods_by_name['get']._options = None
  _PROJECT.methods_by_name['get']._serialized_options = b'\202\323\344\223\002#\022!/identity/v1/project/{project_id}'
  _PROJECT.methods_by_name['list']._options = None
  _PROJECT.methods_by_name['list']._serialized_options = b'\202\323\344\223\0027\022\025/identity/v1/projectsZ\036\"\034/identity/v1/projects/search'
  _PROJECT.methods_by_name['stat']._options = None
  _PROJECT.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\034\"\032/identity/v1/projects/stat'
  _PROJECT.methods_by_name['add_member']._options = None
  _PROJECT.methods_by_name['add_member']._serialized_options = b'\202\323\344\223\002+\")/identity/v1/project/{project_id}/members'
  _PROJECT.methods_by_name['modify_member']._options = None
  _PROJECT.methods_by_name['modify_member']._serialized_options = b'\202\323\344\223\0024\0322/identity/v1/project/{project_id}/member/{user_id}'
  _PROJECT.methods_by_name['remove_member']._options = None
  _PROJECT.methods_by_name['remove_member']._serialized_options = b'\202\323\344\223\0024*2/identity/v1/project/{project_id}/member/{user_id}'
  _PROJECT.methods_by_name['list_members']._options = None
  _PROJECT.methods_by_name['list_members']._serialized_options = b'\202\323\344\223\002_\022)/identity/v1/project/{project_id}/membersZ2\"0/identity/v1/project/{project_id}/members/search'
  _PROJECT.methods_by_name['list_profit_margin_history']._options = None
  _PROJECT.methods_by_name['list_profit_margin_history']._serialized_options = b'\202\323\344\223\002f\022//identity/v1/project/profit-margin-history/listZ3\"1/identity/v1/project/profit-margin-history/search'
  _PROJECT.methods_by_name['create_profit_margin_history']._options = None
  _PROJECT.methods_by_name['create_profit_margin_history']._serialized_options = b'\202\323\344\223\0023\"1/identity/v1/project/profit-margin-history/create'
  _PROJECT.methods_by_name['latest_profit_margin_history']._options = None
  _PROJECT.methods_by_name['latest_profit_margin_history']._serialized_options = b'\202\323\344\223\0023\0221/identity/v1/project/profit-margin-history/latest'
  _PROJECT.methods_by_name['stat_profit_margin_history']._options = None
  _PROJECT.methods_by_name['stat_profit_margin_history']._serialized_options = b'\202\323\344\223\0021\"//identity/v1/project/profit-margin-history/stat'
  _PROJECT.methods_by_name['monthly_profit_margin_history']._options = None
  _PROJECT.methods_by_name['monthly_profit_margin_history']._serialized_options = b'\202\323\344\223\0024\0222/identity/v1/project/profit-margin-history/monthly'
  _CREATEPROJECTREQUEST._serialized_start=274
  _CREATEPROJECTREQUEST._serialized_end=394
  _UPDATEPROJECTREQUEST._serialized_start=397
  _UPDATEPROJECTREQUEST._serialized_end=560
  _PROJECTREQUEST._serialized_start=562
  _PROJECTREQUEST._serialized_end=617
  _GETPROJECTREQUEST._serialized_start=619
  _GETPROJECTREQUEST._serialized_end=691
  _PROJECTQUERY._serialized_start=694
  _PROJECTQUERY._serialized_end=940
  _PROJECTINFO._serialized_start=943
  _PROJECTINFO._serialized_end=1183
  _PROJECTSINFO._serialized_start=1185
  _PROJECTSINFO._serialized_end=1276
  _ADDPROJECTMEMBERREQUEST._serialized_start=1279
  _ADDPROJECTMEMBERREQUEST._serialized_end=1486
  _MODIFYPROJECTMEMBERREQUEST._serialized_start=1489
  _MODIFYPROJECTMEMBERREQUEST._serialized_end=1656
  _REMOVEPROJECTMEMBERREQUEST._serialized_start=1658
  _REMOVEPROJECTMEMBERREQUEST._serialized_end=1742
  _PROJECTMEMBERQUERY._serialized_start=1745
  _PROJECTMEMBERQUERY._serialized_end=1913
  _PROJECTROLEBINDINGINFO._serialized_start=1916
  _PROJECTROLEBINDINGINFO._serialized_end=2319
  _PROJECTROLEBINDINGSINFO._serialized_start=2321
  _PROJECTROLEBINDINGSINFO._serialized_end=2434
  _PROJECTSTATQUERY._serialized_start=2436
  _PROJECTSTATQUERY._serialized_end=2527
  _PROJECT._serialized_start=2530
  _PROJECT._serialized_end=5105
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/plugin/job.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+spaceone/api/cost_analysis/plugin/job.proto\x12!spaceone.api.cost_analysis.plugin\x1a\x1cgoogle/protobuf/struct.proto\"\xb9\x01\n\x0fGetTasksRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\r\n\x05start\x18\x04 \x01(\t\x12\x1c\n\x14last_synchronized_at\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"9\n\x08TaskInfo\x12-\n\x0ctask_options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\"R\n\x0b\x43hangedInfo\x12\r\n\x05start\x18\x01 \x01(\t\x12\x0b\n\x03\x65nd\x18\x02 \x01(\t\x12\'\n\x06\x66ilter\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x88\x01\n\tTasksInfo\x12:\n\x05tasks\x18\x01 \x03(\x0b\x32+.spaceone.api.cost_analysis.plugin.TaskInfo\x12?\n\x07\x63hanged\x18\x02 \x03(\x0b\x32..spaceone.api.cost_analysis.plugin.ChangedInfo2v\n\x03Job\x12o\n\tget_tasks\x12\x32.spaceone.api.cost_analysis.plugin.GetTasksRequest\x1a,.spaceone.api.cost_analysis.plugin.TasksInfo\"\x00\x62\x06proto3')



_GETTASKSREQUEST = DESCRIPTOR.message_types_by_name['GetTasksRequest']
_TASKINFO = DESCRIPTOR.message_types_by_name['TaskInfo']
_CHANGEDINFO = DESCRIPTOR.message_types_by_name['ChangedInfo']
_TASKSINFO = DESCRIPTOR.message_types_by_name['TasksInfo']
GetTasksRequest = _reflection.GeneratedProtocolMessageType('GetTasksRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETTASKSREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.plugin.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.plugin.GetTasksRequest)
  })
_sym_db.RegisterMessage(GetTasksRequest)

TaskInfo = _reflection.GeneratedProtocolMessageType('TaskInfo', (_message.Message,), {
  'DESCRIPTOR' : _TASKINFO,
  '__module__' : 'spaceone.api.cost_analysis.plugin.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.plugin.TaskInfo)
  })
_sym_db.RegisterMessage(TaskInfo)

ChangedInfo = _reflection.GeneratedProtocolMessageType('ChangedInfo', (_message.Message,), {
  'DESCRIPTOR' : _CHANGEDINFO,
  '__module__' : 'spaceone.api.cost_analysis.plugin.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.plugin.ChangedInfo)
  })
_sym_db.RegisterMessage(ChangedInfo)

TasksInfo = _reflection.GeneratedProtocolMessageType('TasksInfo', (_message.Message,), {
  'DESCRIPTOR' : _TASKSINFO,
  '__module__' : 'spaceone.api.cost_analysis.plugin.job_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.plugin.TasksInfo)
  })
_sym_db.RegisterMessage(TasksInfo)

_JOB = DESCRIPTOR.services_by_name['Job']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETTASKSREQUEST._serialized_start=113
  _GETTASKSREQUEST._serialized_end=298
  _TASKINFO._serialized_start=300
  _TASKINFO._serialized_end=357
  _CHANGEDINFO._serialized_start=359
  _CHANGEDINFO._serialized_end=441
  _TASKSINFO._serialized_start=444
  _TASKSINFO._serialized_end=580
  _JOB._serialized_start=582
  _JOB._serialized_end=700
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.notification.v1 import quota_pb2 as spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2


class QuotaStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.notification.v1.Quota/create',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.CreateQuotaRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.notification.v1.Quota/update',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.UpdateQuotaRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.notification.v1.Quota/delete',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.notification.v1.Quota/get',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.notification.v1.Quota/list',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotasInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.notification.v1.Quota/stat',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class QuotaServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Quota limiting the use of a selected Protocol for a day or a month. If the parameter `limit` has no value, it will be deemed unlimited. If a Protocol has not set a Quota, the default Quota set in the Config will be applied.
        request_example: >-
        {
        "protocol_id": "protocol-123456789012",
        "limit": {
        "day": 5.0,
        "month": 7.0
        }
        }
        response_example: >-
        {
        "quota_id": "quota-123456789012",
        "protocol_id": "protocol-123456789012",
        "limit": {
        "day": 5.0,
        "month": 7.0
        },
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Quota. You can make changes in Quota `limit`, managing the use of the Protocol.
        request_example: >-
        {
        "quota_id": "quota-123456789012",
        "limit": {
        "day": 10.0,
        "month": 15.0
        }
        }
        response_example: >-
        {
        "quota_id": "quota-123456789012",
        "protocol_id": "protocol-123456789012",
        "limit": {
        "day": 10.0,
        "month": 15.0
        },
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Quota. The default Quota set in the Config will be applied to the Protocol you deleted the Quota of.
        request_example: >-
        {
        "quota_id": "quota-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Quota. Prints detailed information about the Quota, including the `limit` and the Protocol limited by the Quota.
        request_example: >-
        {
        "quota_id": "quota-123456789012"
        }
        response_example: >-
        {
        "quota_id": "quota-123456789012",
        "protocol_id": "protocol-123456789012",
        "limit": {
        "day": 10.0,
        "month": 15.0
        },
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Quotas. You can use a query to get a filtered list of Quotas.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "quota_id": "quota-123456789012",
        "protocol_id": "protocol-123456789012",
        "limit": {
        "day": 10.0,
        "month": 15.0
        },
        "domain_id": "domain-123456789012"
        },
        {
        "quota_id": "quota-987654321098",
        "protocol_id": "protocol-987654321098",
        "limit": {
        "day": 5.0,
        "month": 7.0
        },
        "domain_id": "domain-123456789012"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_QuotaServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.CreateQuotaRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.UpdateQuotaRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotasInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.notification.v1.Quota', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Quota(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Quota/create',
            spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.CreateQuotaRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Quota/update',
            spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.UpdateQuotaRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Quota/delete',
            spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Quota/get',
            spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaRequest.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Quota/list',
            spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaQuery.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotasInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.Quota/stat',
            spaceone_dot_api_dot_notification_dot_v1_dot_quota__pb2.QuotaStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/identity/v1/endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/identity/v1/endpoint.proto\x12\x18spaceone.api.identity.v1\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xca\x01\n\x0c\x45ndpointInfo\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08\x65ndpoint\x18\x03 \x01(\t\x12\x43\n\x05state\x18\x04 \x01(\x0e\x32\x34.spaceone.api.identity.v1.EndpointInfo.EndpointState\x12\x0f\n\x07version\x18\x05 \x01(\t\"3\n\rEndpointState\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\"v\n\rEndpointQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x15\n\rendpoint_type\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"]\n\rEndpointsInfo\x12\x37\n\x07results\x18\x01 \x03(\x0b\x32&.spaceone.api.identity.v1.EndpointInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xa6\x01\n\x08\x45ndpoint\x12\x99\x01\n\x04list\x12\'.spaceone.api.identity.v1.EndpointQuery\x1a\'.spaceone.api.identity.v1.EndpointsInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x16/identity/v1/endpointsZ\x1f\"\x1d/identity/v1/endpoints/searchb\x06proto3')



_ENDPOINTINFO = DESCRIPTOR.message_types_by_name['EndpointInfo']
_ENDPOINTQUERY = DESCRIPTOR.message_types_by_name['EndpointQuery']
_ENDPOINTSINFO = DESCRIPTOR.message_types_by_name['EndpointsInfo']
_ENDPOINTINFO_ENDPOINTSTATE = _ENDPOINTINFO.enum_types_by_name['EndpointState']
EndpointInfo = _reflection.GeneratedProtocolMessageType('EndpointInfo', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTINFO,
  '__module__' : 'spaceone.api.identity.v1.endpoint_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.EndpointInfo)
  })
_sym_db.RegisterMessage(EndpointInfo)

EndpointQuery = _reflection.GeneratedProtocolMessageType('EndpointQuery', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTQUERY,
  '__module__' : 'spaceone.api.identity.v1.endpoint_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.EndpointQuery)
  })
_sym_db.RegisterMessage(EndpointQuery)

EndpointsInfo = _reflection.GeneratedProtocolMessageType('EndpointsInfo', (_message.Message,), {
  'DESCRIPTOR' : _ENDPOINTSINFO,
  '__module__' : 'spaceone.api.identity.v1.endpoint_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.identity.v1.EndpointsInfo)
  })
_sym_db.RegisterMessage(EndpointsInfo)

_ENDPOINT = DESCRIPTOR.services_by_name['Endpoint']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENDPOINT.methods_by_name['list']._options = None
  _ENDPOINT.methods_by_name['list']._serialized_options = b'\202\323\344\223\0029\022\026/identity/v1/endpointsZ\037\"\035/identity/v1/endpoints/search'
  _ENDPOINTINFO._serialized_start=134
  _ENDPOINTINFO._serialized_end=336
  _ENDPOINTINFO_ENDPOINTSTATE._serialized_start=285
  _ENDPOINTINFO_ENDPOINTSTATE._serialized_end=336
  _ENDPOINTQUERY._serialized_start=338
  _ENDPOINTQUERY._serialized_end=456
  _ENDPOINTSINFO._serialized_start=458
  _ENDPOINTSINFO._serialized_end=551
  _ENDPOINT._serialized_start=554
  _ENDPOINT._serialized_end=720
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/core/v1/server_info.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&spaceone/api/core/v1/server_info.proto\x12\x14spaceone.api.core.v1\x1a\x1bgoogle/protobuf/empty.proto\"\x1e\n\x0bVersionInfo\x12\x0f\n\x07version\x18\x01 \x01(\t2X\n\nServerInfo\x12J\n\x0bget_version\x12\x16.google.protobuf.Empty\x1a!.spaceone.api.core.v1.VersionInfo\"\x00\x62\x06proto3')



_VERSIONINFO = DESCRIPTOR.message_types_by_name['VersionInfo']
VersionInfo = _reflection.GeneratedProtocolMessageType('VersionInfo', (_message.Message,), {
  'DESCRIPTOR' : _VERSIONINFO,
  '__module__' : 'spaceone.api.core.v1.server_info_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.core.v1.VersionInfo)
  })
_sym_db.RegisterMessage(VersionInfo)

_SERVERINFO = DESCRIPTOR.services_by_name['ServerInfo']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _VERSIONINFO._serialized_start=93
  _VERSIONINFO._serialized_end=123
  _SERVERINFO._serialized_start=125
  _SERVERINFO._serialized_end=213
# @@protoc_insertion_point(module_scope)
